@@ -1,9 +1,7 @@
-import os, sys, importlib
 import math
-import time
-import logging
 import numpy as np
-from enum import Enum
+
+import tensorflow as tf
 from .utils import setup_logger
 
 
@@ -56,10 +54,9 @@ class AcquisitionFunction:
             Returns:
                 (numpy.ndarray) Indices
         """
-
-        self.logger.info("Parameters ----")
         self.logger.info("Step-size: {}".format(step_size))
-        self.logger.info(kwargs)
+        self.logger.info("Function: {}".format(self.name))
+        self.logger.info("Kwargs: {}".format(kwargs))
 
         # Set initial acquistion function
         if self.fn is None:
@@ -69,38 +66,30 @@ class AcquisitionFunction:
         # data = pool.get_data()
         # indices = pool.get_indices()
 
-        # Select values randomly? 
-        # No need for batch processing
+        # No need for batch processing, random selection of datapoints.
         if self.name == "random":
-            self.logger.info("Random function")
             return self.fn(indices, data, step_size=step_size, **kwargs)            
 
         # Iterate throug batches of data
         results = None
         num_datapoints = len(data)
-        self.logger.info("Use {} unlabeled datapoints".format(num_datapoints))
-        start = 0
-        # end = self.batch_size if num_datapoints > self.batch_size else num_datapoints
-        end = 0
-        
-        self.logger.info("Kwargs: {}".format(kwargs))
-
-        # ---------
-        # Alternative
+        self.logger.info("Unlabeled Pool size: {}".format(num_datapoints))
+           
+        # Single batch processing
         if self.batch_size is None:
             self.batch_size = len(data)
 
+        # Multi batch Processing
         num_batches = math.ceil(num_datapoints/self.batch_size)
         batches = np.array_split(data, num_batches, axis=0)
         results = []
         for batch in batches:
-
-            sub_result = self.fn(batch, **kwargs)
-            self.logger.info("Result shape: {}".format(sub_result.shape))
-            results.append(sub_result)
-
+            
+            input_tensor = tf.convert_to_tensor(batch)
+            output_tensor = self.fn(input_tensor, **kwargs)
+            results.append(output_tensor)
+        
         stacked = np.hstack(results)
-        self.logger.info("Stacked shaped: {}".format(stacked.shape))
         num_of_elements_to_select = self._adapt_selection_num(len(stacked), step_size)
         return self.__select_first(stacked, indices, num_of_elements_to_select)
 
@@ -109,6 +98,12 @@ class AcquisitionFunction:
         """
             Check if n datapoints are available at all, else adapt the number of datapoints to select.
 
+            Parameters:
+                num_indices (int): The amount of total indices to select from
+                num_to_select (int): The number of datapoints to select
+
+            Returns:
+                (int) the adapted number datapoints to select from a collection.
         """
         if num_indices == 0:
             raise ArgumentError("Can't select {} datapoints, all data is labeled.".format(num_to_select))
@@ -155,13 +150,9 @@ class AcquisitionFunction:
             Returns:
                 (numpy.ndarray): Randomly selected indices for next training.
         """
-        self.logger.info("----------Random-------------")
-
         available_indices = np.linspace(0, len(data)-1, len(data), dtype=int)
         step_size = self._adapt_selection_num(len(available_indices), step_size)
         selected = np.random.choice(available_indices, step_size, replace=False).astype(int)
-
-        self.logger.info("Indices selected: {}".format(selected))
         return indices[selected], data[selected]
 
 
@@ -176,15 +167,8 @@ class AcquisitionFunction:
                 (numpy.ndarray) indices of n-biggest predictions.
         """
         
-        self.logger.info("__select_first/start-sort")
         sorted_keys = np.argsort(predictions)
-        # n_biggest_keys = sorted_keys[-n:]
         n_biggest_keys = sorted_keys[-n:]
-        # other_keys = sorted_keys[:10]
-        # self.logger.info("Other values: {}".format(predictions[other_keys]))
-        # self.logger.info("Values: {}".format(predictions[n_biggest_keys]))
-
-        self.logger.info("__select_first/finish_sort")
         return indices[n_biggest_keys], predictions[n_biggest_keys]
 
 
