@@ -2,7 +2,8 @@ import os, sys, select
 import numpy as np
 import tensorflow as tf
 
-from . import ActiveLearningLoop, AcquisitionFunction, ExperimentSuitMetrics
+from . import ActiveLearningLoop, AcquisitionFunction
+from .wrapper import Model
 from .utils import setup_logger
 
 class ExperimentSuit:
@@ -122,6 +123,7 @@ class ExperimentSuit:
                 query_fn = self.query_functions[j]
 
                 print("Running experiment (Run: {} | Model: {} | Query-Function: {})".format(run, model, query_fn))
+                self.__update_query_function(model, query_fn)
                 self.__run_experiment(run, model, query_fn, seed)
 
                 if (j != (len(self.query_functions)-1) or i != (len(self.models)-1)) \
@@ -204,7 +206,7 @@ class ExperimentSuit:
             raising an error when one of the models can't be processed.
         """
 
-        if isinstance(models, BayesModel):
+        if isinstance(models, Model):
             return [models]
 
         verified_models = []
@@ -212,11 +214,11 @@ class ExperimentSuit:
             for model in models:
                 
                 # Passed model can be used in context of ActiveLearningLoop?
-                if not isinstance(model, BayesModel):
-                    raise ValueError("Error in ExperimentSuit.__init__(). One of the passed models is no sub-class of BayesModel.")
+                if not isinstance(model, Model):
+                    raise ValueError("Error in ExperimentSuit.__init__(). One of the passed models is no sub-class of Model.")
 
         else:
-            raise ValueError("Error in ExperimentSuit.__init__(). Can't parse models of type {}. Expected list of or single BayesModel.".format(type(models)))
+            raise ValueError("Error in ExperimentSuit.__init__(). Can't parse models of type {}. Expected list of or single Model.".format(type(models)))
 
         return models
 
@@ -245,4 +247,33 @@ class ExperimentSuit:
         else:
             raise ValueError("Error in ExperimentSuit.__init__(). Got type {} for qury_fns. Expected a list of strings, AcqusitionFunctions, singel strings or a single AcquisitionFunction.".format(type(query_fns)))
 
-        return fns
\ No newline at end of file
+        return fns
+
+
+    def __update_query_function(self, model, functions):
+        """
+            Update the acquisition function to use new model.
+
+            Parameters:
+                functions (AcquisitionFunction|list(AcquisitionFunction)): The acquisition functions of the experiment
+                model (Model): The model wrapper to use.
+        """
+
+        is_str = isinstance(functions, str)
+        is_obj = isinstance(functions, AcquisitionFunction)
+        is_list = isinstance(functions, list)
+
+        if not (is_obj or is_list or is_str):
+            raise ValueError("Error in ActiveLearningLoop.run(). Failed to update acquisition function for model \"{}\".".format(model.__class__.__name__))
+
+        # Model function will be set in active learning loop
+        if is_str:
+            return
+
+        if is_obj:
+            functions._set_fn(model)
+            return
+        
+        # Update a list of AcquisitionFunction objects
+        for function in functions:
+            function._set_fn(model)
\ No newline at end of file
